@@ -9,21 +9,7 @@ from cms.utils import cms_static_url
 from django.utils import simplejson
 
 class TextEditorWidget(Textarea):
-    class Media:
-        js = [static_url(path) for path in (
-            'ckeditor/ckeditor.js',
-            )] + [
-            cms_static_url(path) for path in(
-            'js/libs/jquery.ui.core.js',
-            'js/placeholder_editor_registry.js',
-        )]
-        css = {
-            'all': [cms_static_url(path) for path in (
-                        'css/jquery/cupertino/jquery-ui.css',
-                    )],
-        }
-
-    def __init__(self, attrs=None, installed_plugins=None):
+    def __init__(self, attrs=None, installed_plugins=None, pk=None):
         """
         Create a widget for editing text + plugins.
 
@@ -34,6 +20,7 @@ class TextEditorWidget(Textarea):
             self.attrs.update(attrs)
         super(TextEditorWidget, self).__init__(attrs)
         self.installed_plugins = installed_plugins
+        self.pk = pk
 
     def render_textarea(self, name, value, attrs=None):
         return super(TextEditorWidget, self).render(name, value, attrs)
@@ -46,6 +33,7 @@ class TextEditorWidget(Textarea):
             'settings': language.join(simplejson.dumps(text_settings.CKEDITOR_SETTINGS).split("{{ language }}")),
             'STATIC_URL': settings.STATIC_URL,
             'installed_plugins': self.installed_plugins,
+            'plugin_pk':self.pk,
         }
         return mark_safe(render_to_string(
             'cms/plugins/widgets/ckeditor.html', context))
